@@ -1,5 +1,6 @@
 import gc
 import re
+import sys
 import operator
 from typing import Callable, Optional, Tuple
 
@@ -142,5 +143,37 @@ def gc_collect():
         gc.collect()
 
 
+NO_COUNT_TYPES: Tuple[type, ...] = ()
+
+if sys.version_info[:2] == (3, 10):
+    # On my laptop there are occasional creations of a single one of these objects
+    # with empty content, which might be some Decimal caching.
+    # Keeping the guard as strict as possible, to be extended if other types
+    # or versions are necessary.
+    try:
+        from _contextvars import Context  # type: ignore
+    except ImportError:
+        pass
+    else:
+        NO_COUNT_TYPES += (Context,)
+
+
+def gc_count() -> int:
+    """
+    len(gc.get_objects()), with subtleties.
+    """
+    if not NO_COUNT_TYPES:
+        return len(gc.get_objects())
+
+    # Note: not using a list comprehension because it pollutes the objects list.
+    rv = 0
+    for obj in gc.get_objects():
+        if isinstance(obj, NO_COUNT_TYPES):
+            continue
+        rv += 1
+
+    return rv
+
+
 async def alist(it):
     return [i async for i in it]
